# estimation.rwolf

`estimation.rwolf(models, param, reps, seed, sampling_method='wild-bootstrap')`

Compute Romano-Wolf adjusted p-values for multiple hypothesis testing.

For each model, it is assumed that tests to adjust are of the form “param = 0”. This function uses the `wildboottest()` method for running the bootstrap, hence models of type `Feiv` or `Fepois` are not supported.

## Parameters

Name | Type | Description | Default
--- | --- | --- | ---
`models` | list[Feols] or FixestMulti | A list of models for which the p-values should be computed, or a FixestMulti object. Models of type `Feiv` or `Fepois` are not supported. | required
`param` | str | The parameter for which the p-values should be computed. | required
`reps` | int | The number of bootstrap replications. | required
`seed` | int | The seed for the random number generator. | required
`sampling_method` | str | Sampling method for computing resampled statistics. Users can choose either bootstrap(‘wild-bootstrap’) or randomization inference(‘ri’) | `'wild-bootstrap'`

## Returns

Type | Description
--- | ---
pd.DataFrame | A DataFrame containing estimation statistics, including the Romano-Wolf adjusted p-values.

## Examples

    from pyfixest.estimation import feols
    from pyfixest.utils import get_data
    from pyfixest.multcomp import rwolf

    data = get_data().dropna()
    fit = feols("Y ~ Y2 + X1 + X2", data=data)
    rwolf(fit.to_list(), "X1", reps=9999, seed=123)

    fit1 = feols("Y ~ X1", data=data)
    fit2 = feols("Y ~ X1 + X2", data=data)
    rwolf_df = rwolf([fit1, fit2], "X1", reps=9999, seed=123)
    rwolf_df